pub struct ToolRegistry { /* private fields */ }Expand description
Registry of typed tools, convertible to provider tool schemas.
Implementations
Sourceimpl ToolRegistry
impl ToolRegistry
pub fn new() -> Self
Sourcepub fn register<TArgs, TResult, Fut, F>(
&mut self,
meta: ToolMeta,
handler: F,
) -> &mut Self
pub fn register<TArgs, TResult, Fut, F>( &mut self, meta: ToolMeta, handler: F, ) -> &mut Self
Register a tool with typed args and typed result.
TArgsmust implementJsonSchemaso we can produce a provider tool schema.- The handler returns a typed result which is serialized to JSON for tool responses.
pub fn specs(&self) -> Vec<ToolSpec>